@@ -1,6 +1,6 @@
 /*                               -*- Mode: C -*- 
  * $Basename: HTWAIS.c $
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
  * Author          : Brewster Kahle, Thinking Machines, <Brewster@think.com>
  * Created On      : Wed Jun 15 17:07:41 1994
  * Last Modified By: Ulrich Pfeifer
@@ -26,7 +26,7 @@
 #endif
 #include "HTWAIS.h"
 
-#define str_get(A) SvPV(A,na)
+#define str_get(A) SvPV_nolen(A)
 #define str_ncat sv_catpvn
 
 #define MAX_MESSAGE_LEN 100000
