@@ -1,6 +1,6 @@
 /*                               -*- Mode: C -*- 
  * $Basename: dictionary.c $
- * $Revision: 1.4 $
+ * $Revision: 1.5 $
  * Author          : Ulrich Pfeifer
  * Created On      : Mon Nov  6 13:34:22 1995
  * Last Modified By: Ulrich Pfeifer
@@ -78,7 +78,7 @@ find_partialword (db, field_name, word, offset, matches)
      long           *matches;
      char           *field_name;
 {
-  register SV   **sp = stack_sp;
+  register SV   **sp = PL_stack_sp;
   long            answer;
   long            number_of_occurances;
   char           *match_word = "initial";
@@ -191,7 +191,7 @@ postings (database_name, field, word, number_of_postings)
      char           *field;
      long           *number_of_postings;
 {
-  register SV   **sp = stack_sp;
+  register SV   **sp = PL_stack_sp;
   database       *db;
   FILE           *stream;
   char           *index_block_header = NULL;
