@@ -12,7 +12,7 @@
 ##
 ## $Id: Wais.pm 1.6 Tue, 07 Apr 1998 16:34:24 +0200 goevert $
 ##
-## $ProjectHeader: Wais 23.11 Mon, 03 Aug 1998 18:56:40 +0200 goevert $
+## $ProjectHeader: Wais 23.16 Fri, 20 Oct 2000 13:07:37 +0200 goevert $
 ######################################################################
 
 
@@ -26,20 +26,20 @@ use strict;
 package Wais;
 
 
-require DynaLoader;
+use base qw(DynaLoader);
+
+
+our $VERSION;
+'$ProjectVersion: 23.16 $ ' =~ /(\d+)\.(\d+)/; $VERSION = $1/10 + $2/1000;
+
 use IO::Socket;
 use IO::Select;
 use Carp;
 
 
-use vars qw(@ISA $CHARS_PER_PAGE $VERSION $timeout $maxnumfd);
-@ISA = qw(DynaLoader);
-
-
-'$ProjectVersion: 23.11 $ ' =~ /(\d+)\.(\d+)/; $VERSION = $1/10 + $2/1000;
-
-$timeout  = 120;
-$maxnumfd = 10;
+our $timeout  = 120;
+our $maxnumfd = 10;
+our $CHARS_PER_PAGE;
 
 bootstrap Wais $VERSION;
 
